from rest_framework.authtoken import views as authtoken_views
from rest_framework.urlpatterns import format_suffix_patterns

from django.conf import settings
from django.urls import path

from api.views import api_root, assemblies, badges, bbb, conferencemember, conferences, events, maps, messages, metanav, rooms, schedule, users

app_name = 'api'
urlpatterns = [
    path('', api_root, name='index'),
    # user data/stuff
    path('me', users.profile, name='profile'),
    path('me/badges.zip', users.BadgeExportView.as_view(), name='badge-export'),
    path('me/badges', users.badges, name='badges'),
    path('me/events', events.EventMyFavorites.as_view(), name='my-events'),
    path('me/events/<uuid:pk>', events.EventMyFavoritesSet.as_view(), name='my-events-set'),
    path('me/received-messages/', messages.DirectMessagesReceived.as_view(), name='my-messages-received'),
    path('me/sent-messages/', messages.DirectMessagesSent.as_view(), name='my-messages-sent'),
    path('me/received-messages/<uuid:pk>', messages.DirectMessageReceived.as_view(), name='my-message-received'),
    path('me/sent-messages/<uuid:pk>', messages.DirectMessageSent.as_view(), name='my-message-sent'),
    path('me/send-message', messages.DirectMessageSend.as_view(), name='my-send-message'),
    path('me/delete-message/<uuid:pk>', messages.DirectMessageDelete.as_view(), name='my-delete-message'),
    path('me/friends', users.friends, name='friends'),
    path('me/timeline', users.UserTimelineList.as_view(), name='timeline-list'),
    # conference-specific views
    path('info', conferences.ConferenceDetail.as_view(), name='conference-detail'),
    path('metanav', metanav.MetaNavView.as_view(), name='conference-metanav'),
    path('schedule', schedule.ConferenceSchedule.as_view(), name='conference-schedule'),
    path('tracks', conferences.ConferenceTrackList.as_view(), name='conferencetrack-list'),
    path('track/<slug:track>/', conferences.ConferenceTrackDetail.as_view(), name='conferencetrack-detail'),
    path('assemblies', assemblies.ConferenceAssemblyList.as_view(), name='assembly-list'),
    path('assembly/<slug:assembly>/', assemblies.ConferenceAssemblyDetail.as_view(), name='assembly-detail'),
    path('assembly/<slug:assembly>/events', assemblies.ConferenceAssemblyEventList.as_view(), name='assembly-events'),
    path('assembly/<slug:assembly>/rooms', assemblies.ConferenceAssemblyRoomList.as_view(), name='assembly-rooms'),
    path('assembly/<slug:assembly>/schedule', schedule.AssemblySchedule.as_view(), name='assembly-schedule'),
    path('assembly/<slug:assembly>/badges', badges.BadgeListCreate.as_view(), name='assembly-badges-list-create'),
    path('assembly/<slug:assembly>/badges/<uuid:pk>', badges.BadgeTokenListCreate.as_view(), name='badge-token-list-create'),
    path('assembly/<slug:assembly>/issue_redeem_token/<str:issuing_token>', badges.BadgeTokenListCreate.as_view(), name='badge-token-create-with-token'),
    path('map/poi.json', maps.PoiExportView.as_view(), name='map-poi'),
    path('map/assemblies/poi.json', maps.AssembliesPoiExportView.as_view(), name='map-assemblies-poi'),
    path('map/assemblies/areas.json', maps.AssembliesAreasExportView.as_view(), name='map-assemblies-areas'),
    path('badges/redeem_token', badges.redeem_badge_token, name='badge-redeem'),
    path('badge/<uuid:pk>/award/user', badges.reward_badge_to_username, name='badge-award-username'),
    path('badge/<uuid:pk>/award/dect', badges.reward_badge_to_dect, name='badge-award-dect'),
    path('rooms', rooms.ConferenceRoomList.as_view(), name='room-list'),
    path('room/<uuid:pk>/', rooms.ConferenceRoomDetail.as_view(), name='room-detail'),
    path('room/<uuid:pk>/schedule', schedule.RoomSchedule.as_view(), name='room-schedule'),
    path('events', events.EventList.as_view(), name='event-list'),
    path('event/<uuid:pk>/', events.EventDetail.as_view(), name='event-detail'),
    path('event/<uuid:pk>/schedule', schedule.EventSchedule.as_view(), name='event-schedule'),
    # integration with other components
    path('integration/c3nav', maps.C3NavExportView.as_view(), name='c3nav'),
    path('integration/is_angel/<str:username>', conferencemember.AngelView.as_view(), name='user-angel'),
]

if settings.INTEGRATIONS_BBB:
    urlpatterns += [
        # BBB meeting ended callback
        path('integration/bbb/meeting_end', bbb.MeetingEnded.as_view(), name='bbb_meeting_end'),
    ]

urlpatterns = format_suffix_patterns(urlpatterns)

urlpatterns += [
    path('auth/get-token', authtoken_views.obtain_auth_token),
]
