from rest_framework import generics

from core.models.assemblies import Assembly
from core.models.events import Event
from core.models.rooms import Room

from api.serializers import AssemblySerializer, EventSerializer, RoomSerializer
from api.views.mixins import ConferenceSlugAssemblyMixin, ConferenceSlugMixin


class ConferenceAssemblyList(ConferenceSlugMixin, generics.ListAPIView):
    serializer_class = AssemblySerializer

    def get_queryset(self, **kwargs):
        return Assembly.objects.conference_accessible(self.conference).order_by('name')


class ConferenceAssemblyDetail(ConferenceSlugAssemblyMixin, generics.RetrieveAPIView):
    serializer_class = AssemblySerializer

    def get_object(self, **kwargs):
        return self.assembly


class ConferenceAssemblyEventList(ConferenceSlugAssemblyMixin, generics.ListAPIView):
    serializer_class = EventSerializer

    def get_queryset(self, **kwargs):
        return Event.objects.conference_accessible(conference=self.conference).filter(room__assembly=self.assembly).order_by('name')


class ConferenceAssemblyRoomList(ConferenceSlugAssemblyMixin, generics.ListAPIView):
    serializer_class = RoomSerializer

    def get_queryset(self, **kwargs):
        return Room.objects.conference_accessible(self.conference).filter(assembly=self.assembly).order_by('name')
