from rest_framework import generics, permissions
from rest_framework.response import Response
from rest_framework.views import APIView

from django.shortcuts import get_object_or_404

from core.models.events import Event

from api.serializers import EventSerializer
from api.views.mixins import ConferenceSlugMixin


class EventList(ConferenceSlugMixin, generics.ListAPIView):
    serializer_class = EventSerializer

    def get_queryset(self, **kwargs):
        return Event.objects.conference_accessible(self.conference).order_by('name')


class EventDetail(ConferenceSlugMixin, generics.RetrieveAPIView):
    serializer_class = EventSerializer

    def get_object(self, **kwargs):
        event_id = self.request.resolver_match.kwargs['pk']
        return get_object_or_404(Event.objects.conference_accessible(conference=self.conference), pk=event_id)


class EventMyFavorites(ConferenceSlugMixin, generics.ListAPIView):
    permission_classes = [permissions.IsAuthenticated]

    def list(self, request, *args, **kwargs):
        return Response(self.request.user.favorite_events.values_list('pk', flat=True))


class EventMyFavoritesSet(ConferenceSlugMixin, APIView):
    permission_classes = [permissions.IsAuthenticated]

    def put(self, request, *args, pk=None, **kwargs):
        self.request.user.favorite_events.add(*Event.objects.conference_accessible(conference=self.conference).filter(pk=pk))
        return Response(True)

    def delete(self, request, *args, pk=None, **kwargs):
        self.request.user.favorite_events.remove(*Event.objects.conference_accessible(conference=self.conference).filter(pk=pk))
        return Response(True)
