import logging

from django.contrib import messages
from django.shortcuts import redirect
from django.views.generic import DetailView, ListView

from core.models import StaticPage

from backoffice.views.moderation.mixins import ModerationAdminMixin

logger = logging.getLogger(__name__)


class ModerationWikiListView(ModerationAdminMixin, ListView):
    template_name = 'backoffice/moderation_wiki-list.html'

    def get_queryset(self):
        qs = self.conference.pages.all()
        return qs


class ModerationWikiDetailView(ModerationAdminMixin, DetailView):
    template_name = 'backoffice/moderation_wiki-detail.html'

    def get_queryset(self):
        qs = self.conference.pages.all()
        return qs

    def post(self, request, *args, **kwargs):
        page = self.get_object()
        action = request.POST.get('action')

        # TODO: add log entries
        if action == 'hide':
            page.privacy = StaticPage.Privacy.PERM
            page.save(update_fields=['privacy'])
            messages.success(request, f'page "{page.slug}" ({page.language}) set non-public: {page.id}')

        elif action == 'protect':
            page.protection = StaticPage.Protection.PERM
            page.save(update_fields=['protection'])
            messages.success(request, f'page "{page.slug}" ({page.language}) set protected: {page.id}')

        elif action == 'unprotect':
            page.protection = StaticPage.Protection.NONE
            page.save(update_fields=['protection'])
            messages.success(request, f'page "{page.slug}" ({page.language}) removed protection: {page.id}')

        elif action == 'delete':
            page_id = page.id
            page.delete()
            messages.success(request, f'page "{page.slug}" ({page.language}) deleted: {page_id}')
            return redirect('backoffice:moderation-wiki-list')

        else:
            messages.error(request, f'UNKNOWN ACTION: {action}')

        return redirect('backoffice:moderation-wiki-detail', pk=page.pk)
